/*!
 * @eslint-sets/eslint-config-svelte v5.8.0
 * Eslint config sets for svelte
 * (c) 2021-2023 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
'use strict';

var localPkg = require('local-pkg');

var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
const tsExits = localPkg.isPackageExists("typescript");
if (!tsExits)
  console.warn("[@eslint-sets/eslint-config] TypeScript is not installed, fallback to JS only.");
const config = {
  plugins: [
    tsExits ? "tsdoc" : "jsdoc",
    "prettier"
    // 'import'
  ],
  extends: [
    tsExits ? "plugin:@typescript-eslint/recommended" : "plugin:jsdoc/recommended",
    "plugin:svelte/recommended",
    tsExits ? "@eslint-sets/eslint-config-ts" : "@eslint-sets/eslint-config-basic",
    "plugin:vitest-globals/recommended",
    "prettier"
  ],
  rules: {},
  globals: {
    h: true,
    jest: "readonly"
  },
  overrides: [
    {
      files: ["**/__tests__/*.{j,t}s?(x)", "**/*.spec.{j,t}s?(x)"],
      env: {
        mocha: true,
        jest: true
      },
      rules: {
        "no-console": "off"
      }
    },
    {
      files: ["*.svelte"],
      parser: "svelte-eslint-parser",
      parserOptions: {
        parser: "@typescript-eslint/parser",
        ecmaVersion: "latest",
        sourceType: "module",
        ecmaFeatures: {
          // globalReturn: false,
          // impliedStrict: false,
          experimentalObjectRestSpread: true,
          experimentalDecorators: true,
          jsx: true,
          tsx: true
        }
      },
      rules: __spreadValues({}, tsExits ? { "@typescript-eslint/no-unused-vars": "off" } : null)
    }
  ]
};
if (config.rules && !tsExits) {
  config.rules["jsdoc/tag-lines"] = [1, "any", { startLines: 1 }];
}

module.exports = config;
